diff --git a/src/backend/commands/event_trigger.c b/src/backend/commands/event_trigger.c
index cc10c5e..1c4f12d 100644
--- a/src/backend/commands/event_trigger.c
+++ b/src/backend/commands/event_trigger.c
@@ -1657,6 +1657,10 @@ EventTriggerCollectSimpleCommand(ObjectAddress address,
 	MemoryContext oldcxt;
 	CollectedCommand *command;
 
+	/* ignore if no objects to operate on */
+	if (ObjectAddressEq(address, InvalidObjectAddress))
+		return;
+
 	/* ignore if event trigger context not set, or collection disabled */
 	if (!currentEventTriggerState ||
 		currentEventTriggerState->commandCollectionInhibited)
diff --git a/src/backend/commands/functioncmds.c b/src/backend/commands/functioncmds.c
index 4accf76..dbbb2d3 100644
--- a/src/backend/commands/functioncmds.c
+++ b/src/backend/commands/functioncmds.c
@@ -1740,7 +1740,7 @@ check_transform_function(Form_pg_proc procstruct)
 /*
  * CREATE TRANSFORM
  */
-Oid
+ObjectAddress
 CreateTransform(CreateTransformStmt *stmt)
 {
 	Oid			typeid;
@@ -1938,7 +1938,7 @@ CreateTransform(CreateTransformStmt *stmt)
 
 	heap_close(relation, RowExclusiveLock);
 
-	return transformid;
+	return myself;
 }
 
 
diff --git a/src/backend/tcop/utility.c b/src/backend/tcop/utility.c
index 7db9f96..21aa7dc 100644
--- a/src/backend/tcop/utility.c
+++ b/src/backend/tcop/utility.c
@@ -912,8 +912,7 @@ ProcessUtilitySlow(Node *parsetree,
 	bool		isTopLevel = (context == PROCESS_UTILITY_TOPLEVEL);
 	bool		isCompleteQuery = (context <= PROCESS_UTILITY_QUERY);
 	bool		needCleanup;
-	bool		commandCollected = false;
-	ObjectAddress address;
+	ObjectAddress address = InvalidObjectAddress;
 	ObjectAddress secondaryObject = InvalidObjectAddress;
 
 	/* All event trigger calls are done only when isCompleteQuery is true */
@@ -938,7 +937,6 @@ ProcessUtilitySlow(Node *parsetree,
 				 * EventTriggerCollectSimpleCommand called by
 				 * CreateSchemaCommand
 				 */
-				commandCollected = true;
 				break;
 
 			case T_CreateStmt:
@@ -1026,9 +1024,9 @@ ProcessUtilitySlow(Node *parsetree,
 
 					/*
 					 * The multiple commands generated here are stashed
-					 * individually, so disable collection below.
+					 * individually, so collection is disabled.
 					 */
-					commandCollected = true;
+					address = InvalidObjectAddress;
 				}
 				break;
 
@@ -1106,7 +1104,6 @@ ProcessUtilitySlow(Node *parsetree,
 				}
 
 				/* ALTER TABLE stashes commands internally */
-				commandCollected = true;
 				break;
 
 			case T_AlterDomainStmt:
@@ -1272,7 +1269,7 @@ ProcessUtilitySlow(Node *parsetree,
 					 */
 					EventTriggerCollectSimpleCommand(address, secondaryObject,
 													 parsetree);
-					commandCollected = true;
+					address = InvalidObjectAddress;
 					EventTriggerAlterTableEnd();
 				}
 				break;
@@ -1317,13 +1314,11 @@ ProcessUtilitySlow(Node *parsetree,
 			case T_DropUserMappingStmt:
 				RemoveUserMapping((DropUserMappingStmt *) parsetree);
 				/* no commands stashed for DROP */
-				commandCollected = true;
 				break;
 
 			case T_ImportForeignSchemaStmt:
 				ImportForeignSchema((ImportForeignSchemaStmt *) parsetree);
 				/* commands are stashed inside ImportForeignSchema */
-				commandCollected = true;
 				break;
 
 			case T_CompositeTypeStmt:	/* CREATE TYPE (composite) */
@@ -1353,7 +1348,7 @@ ProcessUtilitySlow(Node *parsetree,
 				EventTriggerCollectSimpleCommand(address, secondaryObject,
 												 parsetree);
 				/* stashed internally */
-				commandCollected = true;
+				address = InvalidObjectAddress;
 				EventTriggerAlterTableEnd();
 				break;
 
@@ -1430,7 +1425,6 @@ ProcessUtilitySlow(Node *parsetree,
 			case T_CreateOpClassStmt:
 				DefineOpClass((CreateOpClassStmt *) parsetree);
 				/* command is stashed in DefineOpClass */
-				commandCollected = true;
 				break;
 
 			case T_CreateOpFamilyStmt:
@@ -1438,13 +1432,12 @@ ProcessUtilitySlow(Node *parsetree,
 				break;
 
 			case T_CreateTransformStmt:
-				CreateTransform((CreateTransformStmt *) parsetree);
+				address = CreateTransform((CreateTransformStmt *) parsetree);
 				break;
 
 			case T_AlterOpFamilyStmt:
 				AlterOpFamily((AlterOpFamilyStmt *) parsetree);
 				/* commands are stashed in AlterOpFamily */
-				commandCollected = true;
 				break;
 
 			case T_AlterTSDictionaryStmt:
@@ -1458,13 +1451,11 @@ ProcessUtilitySlow(Node *parsetree,
 			case T_AlterTableMoveAllStmt:
 				AlterTableMoveAll((AlterTableMoveAllStmt *) parsetree);
 				/* commands are stashed in AlterTableMoveAll */
-				commandCollected = true;
 				break;
 
 			case T_DropStmt:
 				ExecDropStmt((DropStmt *) parsetree, isTopLevel);
 				/* no commands stashed for DROP */
-				commandCollected = true;
 				break;
 
 			case T_RenameStmt:
@@ -1488,19 +1479,16 @@ ProcessUtilitySlow(Node *parsetree,
 			case T_GrantStmt:
 				ExecuteGrantStmt((GrantStmt *) parsetree);
 				/* commands are stashed in ExecGrantStmt_oids */
-				commandCollected = true;
 				break;
 
 			case T_DropOwnedStmt:
 				DropOwnedObjects((DropOwnedStmt *) parsetree);
 				/* no commands stashed for DROP */
-				commandCollected = true;
 				break;
 
 			case T_AlterDefaultPrivilegesStmt:
 				ExecAlterDefaultPrivilegesStmt((AlterDefaultPrivilegesStmt *) parsetree);
 				EventTriggerCollectAlterDefPrivs((AlterDefaultPrivilegesStmt *) parsetree);
-				commandCollected = true;
 				break;
 
 			case T_CreatePolicyStmt:	/* CREATE POLICY */
@@ -1525,9 +1513,8 @@ ProcessUtilitySlow(Node *parsetree,
 		 * Remember the object so that ddl_command_end event triggers have
 		 * access to it.
 		 */
-		if (!commandCollected)
-			EventTriggerCollectSimpleCommand(address, secondaryObject,
-											 parsetree);
+		EventTriggerCollectSimpleCommand(address, secondaryObject,
+										 parsetree);
 
 		if (isCompleteQuery)
 		{
diff --git a/src/include/catalog/objectaddress.h b/src/include/catalog/objectaddress.h
index 37808c0..de8015d 100644
--- a/src/include/catalog/objectaddress.h
+++ b/src/include/catalog/objectaddress.h
@@ -40,6 +40,11 @@ extern const ObjectAddress InvalidObjectAddress;
 #define ObjectAddressSet(addr, class_id, object_id) \
 	ObjectAddressSubSet(addr, class_id, object_id, 0)
 
+#define ObjectAddressEq(addr, addr2) \
+	((addr).classId == (addr2).classId && \
+	 (addr).objectId == (addr2).objectId && \
+	 (addr).objectSubId == (addr2).objectSubId)
+
 extern ObjectAddress get_object_address(ObjectType objtype, List *objname,
 				   List *objargs, Relation *relp,
 				   LOCKMODE lockmode, bool missing_ok);
diff --git a/src/include/commands/defrem.h b/src/include/commands/defrem.h
index dcb6c08..9b81c16 100644
--- a/src/include/commands/defrem.h
+++ b/src/include/commands/defrem.h
@@ -51,7 +51,7 @@ extern void SetFunctionArgType(Oid funcOid, int argIndex, Oid newArgType);
 extern ObjectAddress AlterFunction(AlterFunctionStmt *stmt);
 extern ObjectAddress CreateCast(CreateCastStmt *stmt);
 extern void DropCastById(Oid castOid);
-extern Oid	CreateTransform(CreateTransformStmt *stmt);
+extern ObjectAddress CreateTransform(CreateTransformStmt *stmt);
 extern void DropTransformById(Oid transformOid);
 extern void IsThereFunctionInNamespace(const char *proname, int pronargs,
 						   oidvector *proargtypes, Oid nspOid);
diff --git a/src/test/modules/test_ddl_deparse/Makefile b/src/test/modules/test_ddl_deparse/Makefile
index 13b985a..8ea6f39 100644
--- a/src/test/modules/test_ddl_deparse/Makefile
+++ b/src/test/modules/test_ddl_deparse/Makefile
@@ -15,6 +15,7 @@ REGRESS = test_ddl_deparse \
 	create_domain \
 	create_sequence_1 \
 	create_table \
+	create_transform \
 	alter_table \
 	create_view \
 	create_trigger \
diff --git a/src/test/modules/test_ddl_deparse/expected/create_transform.out b/src/test/modules/test_ddl_deparse/expected/create_transform.out
new file mode 100644
index 0000000..0d1cc36
--- /dev/null
+++ b/src/test/modules/test_ddl_deparse/expected/create_transform.out
@@ -0,0 +1,13 @@
+--
+-- CREATE_TRANSFORM
+--
+-- Create a dummy transform
+-- The function FROM SQL should have internal as single argument as well
+-- as return type. The function TO SQL should have as single argument
+-- internal and as return argument the datatype of the transform done.
+-- pl/plpgsql does not authorize the use of internal as data type.
+CREATE TRANSFORM FOR int LANGUAGE SQL (
+    FROM SQL WITH FUNCTION varchar_transform(internal),
+    TO SQL WITH FUNCTION int4recv(internal));
+NOTICE:  DDL test: type simple, tag CREATE TRANSFORM
+DROP TRANSFORM FOR int LANGUAGE SQL;
diff --git a/src/test/modules/test_ddl_deparse/sql/create_transform.sql b/src/test/modules/test_ddl_deparse/sql/create_transform.sql
new file mode 100644
index 0000000..0968702
--- /dev/null
+++ b/src/test/modules/test_ddl_deparse/sql/create_transform.sql
@@ -0,0 +1,14 @@
+--
+-- CREATE_TRANSFORM
+--
+
+-- Create a dummy transform
+-- The function FROM SQL should have internal as single argument as well
+-- as return type. The function TO SQL should have as single argument
+-- internal and as return argument the datatype of the transform done.
+-- pl/plpgsql does not authorize the use of internal as data type.
+CREATE TRANSFORM FOR int LANGUAGE SQL (
+    FROM SQL WITH FUNCTION varchar_transform(internal),
+    TO SQL WITH FUNCTION int4recv(internal));
+
+DROP TRANSFORM FOR int LANGUAGE SQL;
